import { useState, useEffect } from "react";
import Cookies from "js-cookie";
import axios from "axios";

// Heart Icon Component (SVG)
const Heart = ({ onClick, isActive, size, className }) => (
  <svg
    onClick={onClick}
    className={`${className} ${
      isActive ? "text-red-500 fill-current" : "text-gray-500"
    }`}
    width={size}
    height={size}
    viewBox="0 0 24 24"
    fill={isActive ? "currentColor" : "none"}
    stroke="currentColor"
    strokeWidth="2"
  >
    <path d="M12 21.35l-1.45-1.32C5.4 15.36 2 12.28 2 8.5 2 5.42 4.42 3 7.5 3c1.74 0 3.41.81 4.5 2.09C13.09 3.81 14.76 3 16.5 3 19.58 3 22 5.42 22 8.5c0 3.78-3.4 6.86-8.55 11.54L12 21.35z" />
  </svg>
);

const WishlistButton = ({ item }) => {
  const [isActive, setIsActive] = useState(false); // Tracks if product is in wishlist
  const token = Cookies.get("access_token");

  // Fetch wishlist on mount to set initial state
  useEffect(() => {
    const fetchWishlist = async () => {
      try {
        const response = await axios.get(
          `${process.env.NEXT_PUBLIC_BASE_URL}getWishlist`,
          {
            headers: {
              Authorization: `Bearer ${token}`,
              "Content-Type": "application/json",
            },
          }
        );
        console.log(response.data);

        if (response.data.success) {
          const wishlist = response.data.wishlist;
          // Check if current product is in wishlist
          setIsActive(wishlist.some((w) => w.product_id === item.product_id));
        }
      } catch (error) {
        console.error("Error fetching wishlist:", error);
      }
    };
    if (token) {
      fetchWishlist();
    }
  }, [item.product_id, token]);

  const handleWishList = async (product_id) => {
    // Optimistically update UI
    const previousState = isActive;
    setIsActive(!isActive);

    try {
      const orderData = { product_id };

      const response = await axios.post(
        `${process.env.NEXT_PUBLIC_BASE_URL}toggleWishlist`,
        orderData,
        {
          headers: {
            Authorization: `Bearer ${token}`,
            "Content-Type": "application/json",
          },
        }
      );

      // Revert optimistic update if request fails
      if (response.status !== 200) {
        setIsActive(previousState);
      }
    } catch (error) {
      console.error("Error toggling wishlist:", error);
      setIsActive(previousState); // Revert on error
    }
  };

  // Disable button if no token
  if (!token) {
    return <Heart size={18} className="text-gray-300 cursor-not-allowed" />;
  }

  return (
    <Heart
      onClick={() => handleWishList(item.product_id)}
      isActive={isActive}
      size={18}
      className="cursor-pointer"
    />
  );
};

export default WishlistButton;
